@@ -45,7 +45,7 @@
 extern "C" {
 #endif
 
-#define GETDNS_COMPILATION_COMMENT "getdns 1.4.2 configured on 2018-09-15T12:22:33Z for the December 2015 version of the API"
+#define GETDNS_COMPILATION_COMMENT "getdns 1.5.0 configured on 2018-12-23T12:47:50Z for the December 2015 version of the API"
 
 /**
  * \defgroup functions Functions
@@ -416,6 +416,7 @@ typedef enum getdns_callback_type_t {
 #define GETDNS_RRTYPE_CDNSKEY   60
 #define GETDNS_RRTYPE_OPENPGPKEY 61
 #define GETDNS_RRTYPE_CSYNC     62
+#define GETDNS_RRTYPE_ZONEMD    63
 #define GETDNS_RRTYPE_SPF       99
 #define GETDNS_RRTYPE_UINFO     100
 #define GETDNS_RRTYPE_UID       101
@@ -743,7 +744,7 @@ getdns_list *getdns_list_create();
  *                used to create and initialize the list.
  * @return pointer to an allocated list, NULL if insufficient memory
  */
-getdns_list *getdns_list_create_with_context(getdns_context *context);
+getdns_list *getdns_list_create_with_context(const getdns_context *context);
 
 /**
  * create a new list with no items, creating and initializing it with the
@@ -863,7 +864,7 @@ getdns_dict *getdns_dict_create();
  *                used to create and initialize the dict.
  * @return pointer to an allocated dict, NULL if insufficient memory
  */
-getdns_dict *getdns_dict_create_with_context(getdns_context *context);
+getdns_dict *getdns_dict_create_with_context(const getdns_context *context);
 
 /**
  * create a new dict with no items, creating and initializing it with the
@@ -1030,9 +1031,9 @@ getdns_return_t
 getdns_general(getdns_context *context,
     const char *name,
     uint16_t request_type,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     void *userarg,
-    getdns_transaction_t * transaction_id, getdns_callback_t callbackfn);
+    getdns_transaction_t *transaction_id, getdns_callback_t callbackfn);
 
 /**
  * retrieve address assigned to a DNS name
@@ -1048,9 +1049,9 @@ getdns_general(getdns_context *context,
 getdns_return_t
 getdns_address(getdns_context *context,
     const char *name,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     void *userarg,
-    getdns_transaction_t * transaction_id, getdns_callback_t callbackfn);
+    getdns_transaction_t *transaction_id, getdns_callback_t callbackfn);
 
 /**
  * retrieve hostname assigned to an IP address
@@ -1065,10 +1066,10 @@ getdns_address(getdns_context *context,
  */
 getdns_return_t
 getdns_hostname(getdns_context *context,
-    getdns_dict *address,
-    getdns_dict *extensions,
+    const getdns_dict *address,
+    const getdns_dict *extensions,
     void *userarg,
-    getdns_transaction_t * transaction_id, getdns_callback_t callbackfn);
+    getdns_transaction_t *transaction_id, getdns_callback_t callbackfn);
 
 /**
  * retrieve a service assigned to a DNS name
@@ -1084,9 +1085,9 @@ getdns_hostname(getdns_context *context,
 getdns_return_t
 getdns_service(getdns_context *context,
     const char *name,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     void *userarg,
-    getdns_transaction_t * transaction_id, getdns_callback_t callbackfn);
+    getdns_transaction_t *transaction_id, getdns_callback_t callbackfn);
 /** @}
  */
 
@@ -1201,7 +1202,7 @@ getdns_return_t
 getdns_general_sync(getdns_context *context,
     const char *name,
     uint16_t request_type,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     getdns_dict **response);
 
 /**
@@ -1216,7 +1217,7 @@ getdns_general_sync(getdns_context *context,
 getdns_return_t
 getdns_address_sync(getdns_context *context,
     const char *name,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     getdns_dict **response);
 
 /**
@@ -1230,8 +1231,8 @@ getdns_address_sync(getdns_context *context,
  */
 getdns_return_t
 getdns_hostname_sync(getdns_context *context,
-    getdns_dict *address,
-    getdns_dict *extensions,
+    const getdns_dict *address,
+    const getdns_dict *extensions,
     getdns_dict **response);
 
 /**
@@ -1246,7 +1247,7 @@ getdns_hostname_sync(getdns_context *context,
 getdns_return_t
 getdns_service_sync(getdns_context *context,
     const char *name,
-    getdns_dict *extensions,
+    const getdns_dict *extensions,
     getdns_dict **response);
 
 /** @}
@@ -1341,9 +1342,8 @@ char *getdns_convert_alabel_to_ulabel(const char *alabel);
  * depending on the validation status.
  */
 getdns_return_t
-getdns_validate_dnssec(getdns_list *to_validate,
-    getdns_list *support_records,
-    getdns_list *trust_anchors);
+getdns_validate_dnssec(const getdns_list *to_validate,
+    const getdns_list *support_records, const getdns_list *trust_anchors);
 
 /**
  * Get the default list of trust anchor records that is used by the library
@@ -1444,7 +1444,7 @@ getdns_context_set_resolution_type(getdns_context *context,
  */
 getdns_return_t
 getdns_context_set_namespaces(getdns_context *context,
-    size_t namespace_count, getdns_namespace_t *namespaces);
+    size_t namespace_count, const getdns_namespace_t *namespaces);
 
 /**
  * Specifies what transport are used for DNS lookups. The default is
@@ -1812,9 +1812,11 @@ getdns_context_set_extended_memory_functions(getdns_context *context,
  *            GETDNS_RESOLUTION_STUB.
  *         - all_context (a dict) with names for all the other settings in
  *           context.
+ *         The application is responsible for cleaning up the returned dictionary 
+ *         object with getdns_dict_destroy.
  */
 getdns_dict*
-getdns_context_get_api_information(getdns_context* context);
+getdns_context_get_api_information(const getdns_context *context);
 
 /** @}
  */
